@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2015
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2020
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -23,7 +24,6 @@
 #include "polymake/linalg.h"
 #include "polymake/IncidenceMatrix.h"
 #include "polymake/FacetList.h"
-#include "polymake/polytope/minkowski_sum_fukuda.h"
 
 namespace polymake { namespace fan {
 
@@ -39,8 +39,8 @@ Matrix<E> express_in_basis(const Matrix<E>& A, const Matrix<E>& B)
          throw std::runtime_error("solve_system - incompatible matrix");
    }
    Matrix<E> res(B.rows(), A.rows());
-   typename Entire<Rows<Matrix<E> > >::iterator rit = entire(rows(res));
-   for (typename Entire<Rows<Matrix<E> > >::const_iterator bit = entire(rows(B)); !bit.at_end(); ++bit, ++rit) 
+   auto rit = entire(rows(res));
+   for (auto bit = entire(rows(B)); !bit.at_end(); ++bit, ++rit) 
       *rit = lin_solve(T(A), *bit);
    return res;
 }
@@ -48,9 +48,9 @@ Matrix<E> express_in_basis(const Matrix<E>& A, const Matrix<E>& B)
 }  // end anonymous namespace
 
 template <typename E>
-perl::Object tiling_quotient(perl::Object P, perl::Object Q)
+BigObject tiling_quotient(BigObject P, BigObject Q)
 {
-   const int
+   const Int
       d = P.give("COMBINATORIAL_DIM"),
       e = Q.give("COMBINATORIAL_DIM");
    if (d!=e) throw std::runtime_error("The dimensions of P and Q must be equal");
@@ -74,13 +74,15 @@ perl::Object tiling_quotient(perl::Object P, perl::Object Q)
    VQL -= repeat_row(barycenter, VQL.rows());
 
    // Take the Minkowski sum of the transformed P and Q 
-   Array<perl::Object> summands(perl::ObjectType::construct<E>("Polytope"), 2);
-   summands[0].take("VERTICES") << (ones_vector<E>() | VPL);
-   summands[1].take("VERTICES") << (ones_vector<E>() | VQL);
-   const Matrix<E> MV = polytope::minkowski_sum_vertices_fukuda<E>(summands);
+   BigObjectType Polytope("Polytope", mlist<E>());
+   BigObject summand1(Polytope);
+   BigObject summand2(Polytope);
+   summand1.take("VERTICES") << (ones_vector<E>() | VPL);
+   summand2.take("VERTICES") << (ones_vector<E>() | VQL);
+   const Matrix<E> MV = call_function("polytope::minkowski_sum_vertices_fukuda", mlist<E>(), summand1, summand2);
 
    // Find the interior and boundary lattice points of the Minkowski sum
-   perl::Object M(perl::ObjectType::construct<E>("Polytope"));
+   BigObject M("Polytope", mlist<E>());
    M.take("VERTICES") << MV;
    const Matrix<E> 
       ILP = M.give("INTERIOR_LATTICE_POINTS"),
@@ -91,11 +93,11 @@ perl::Object tiling_quotient(perl::Object P, perl::Object Q)
    // get the facets of the transformed polytopes.
    // of course, we could calculate these directly...
    const Matrix<E> 
-      FP = summands[0].give("FACETS"),
-      FQ = summands[1].give("FACETS");
+      FP = summand1.give("FACETS"),
+      FQ = summand2.give("FACETS");
 
-   Map<Vector<E>, int> index_of;
-   int n(0);
+   Map<Vector<E>, Int> index_of;
+   Int n = 0;
 
    // We will store the cells of the complex in a FacetList.
    // Initially, we reserve space for #vert Q vertices, 
@@ -107,24 +109,24 @@ perl::Object tiling_quotient(perl::Object P, perl::Object Q)
    // - intersect the translate with P 
    // - if the intersection is full-dimensional, store it
    ListMatrix<Vector<E> > coos(0, d+1);
-   for (typename Entire<Rows<Matrix<E> > >::const_iterator lit = entire(rows(LPm)); !lit.at_end(); ++lit) {
+   for (auto lit = entire(rows(LPm)); !lit.at_end(); ++lit) {
       // translate Q by *lit 
       Matrix<E> translated_facets(FQ);
-      translated_facets.col(0) -= FQ.minor(All, ~scalar2set(0)) * (*lit);
+      translated_facets.col(0) -= FQ.minor(All, range_from(1)) * (*lit);
 
       // intersect the translated polytope with P
-      perl::Object Cell(perl::ObjectType::construct<E>("Polytope"));
+      BigObject Cell("Polytope", mlist<E>());
       Cell.take("INEQUALITIES") << (translated_facets / FP);
 
       // only proceed with full-dimensional faces
-      const int dd = Cell.give("COMBINATORIAL_DIM");
+      const Int dd = Cell.give("COMBINATORIAL_DIM");
       if (dd != d) continue;
 
       const Matrix<E> translated_vertices = Cell.give("VERTICES");
 
       // translate back, simultaneously store vertices and cell information
-      Set<int> vif;
-      for (typename Entire<Rows<Matrix<E> > >::const_iterator rit = entire(rows(translated_vertices)); !rit.at_end(); ++rit) {
+      Set<Int> vif;
+      for (auto rit = entire(rows(translated_vertices)); !rit.at_end(); ++rit) {
          // translate back from the lattice point and undo the translation of the barycenter 
          const Vector<E> v (dehomogenize(*rit) - *lit + barycenter);
          const Vector<E> inhv = 1 | (v * L);   // ... and undo the linear transform
@@ -138,7 +140,7 @@ perl::Object tiling_quotient(perl::Object P, perl::Object Q)
    }
 
    // done
-   perl::Object PS(perl::ObjectType::construct<E>("PolyhedralComplex"));
+   BigObject PS("PolyhedralComplex", mlist<E>());
    PS.take("VERTICES") << coos;
    PS.take("MAXIMAL_POLYTOPES") << F;
    return PS;
