@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2020
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -19,16 +20,16 @@
 
 namespace polymake { namespace graph {
 
-perl::Object complete_bipartite(const int k, const int l)
+BigObject complete_bipartite(const Int k, const Int l)
 {
    if (k < 1 || l < 1)
       throw std::runtime_error("number of nodes on both parts must be positive");
 
    Graph<> g(k+l);
-   for (int i=0; i<k; ++i)
-     for (int j=k; j<k+l; ++j)
+   for (Int i = 0; i < k; ++i)
+     for (Int j = k; j < k+l; ++j)
        g.edge(i,j);
-   perl::Object G("Graph<>");
+   BigObject G("Graph<>");
    G.take("N_NODES")<<(k+l);
    G.take("N_EDGES")<<(k*l);
    G.take("DIAMETER")<<2;
@@ -40,7 +41,7 @@ perl::Object complete_bipartite(const int k, const int l)
    return G;
 
 }
-UserFunction4perl("# @category Producing a graph\n"
+UserFunction4perl("# @category Producing a graph"
                   "# Constructs a __complete bipartite graph__ on //k// + //l// nodes."
                   "# @param Int k"
                   "# @param Int l"
